@@ -200,7 +200,7 @@ def curl(ctx, command):
 	command = list(command)
 	command = ['-s', '-v', '-H', 'X-Sail-Profile: %s' % config['profile_key']] + command
 
-	util.heading('Running cURL with profiling headers', err=True)
+	util.heading('Running cURL with profiling headers')
 
 	# TODO: Maybe add the SAIL_NOCACHE query var
 	p = subprocess.Popen(['curl'] + command, stdout=subprocess.PIPE,
@@ -211,7 +211,7 @@ def curl(ctx, command):
 	if p.returncode != 0:
 		raise util.SailException('An error occurred in cURL. Please try again.')
 
-	matches = re.search(r'^<\s*X-Sail-Profile: (.+)$', stderr, re.MULTILINE)
+	matches = re.search(r'^<\s*X-Sail-Profile: (.+)$', stderr, re.MULTILINE | re.IGNORECASE)
 	if not matches:
 		raise util.SailException('Could not find profile filename from headers')
 
@@ -439,13 +439,16 @@ def _render_view_symbol(stdscr, data, totals, symbol, selected=1, sort=2):
 		'mysql_query',
 		'curl_exec',
 		'mysqli::query',
-		'{closure}',
 	]
 
 	if '#' in symbol:
 		item['label'], args = symbol.split('#', 1)
 
-		if item['label'] in expand_meta_for:
+		expand = True if item['label'] in expand_meta_for else False
+		if item['label'].endswith('{closure}'):
+			expand = True
+
+		if expand:
 			meta = []
 			for line in textwrap.wrap(args, cols - 4):
 				meta.append({'meta': line})
