@@ -10,11 +10,11 @@ import re, secrets, string
 import shlex, time, io, pathlib, jinja2
 import packaging.version
 
+from types import SimpleNamespace
+
 from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography.hazmat.primitives import serialization
 
-from prettytable import PrettyTable
-
 @cli.command()
 @click.option('--provider-token', help='Your DigitalOcean API token, must be read-write. You can set a default token with: sail config provider-token <token>')
 @click.option('--size', default='s-1vcpu-1gb-intel', help='The Droplet size, defaults to s-1vcpu-1gb-intel. To get a full list of available sizes and pricing run: sail sizes')
@@ -23,12 +23,16 @@ from prettytable import PrettyTable
 @click.option('--namespace', default='default', help='The namespace to use for the new application')
 @click.option('--environment', help='Initialize the application into an existing environment')
 @click.option('--blueprint', 'blueprint', default='default.yaml', help='Apply a blueprint after init, defaults to: default.yaml')
+@click.option('--json', 'as_json', is_flag=True, help='Suspend regular output and print results in JSON format')
 @click.option('--force', '-f', is_flag=True)
 @click.pass_context
-def init(ctx, provider_token, email, size, region, force, namespace, environment, blueprint):
+def init(ctx, provider_token, email, size, region, force, namespace, environment, blueprint, as_json):
 	'''Initialize and provision a new project'''
 	root = util.find_root()
 
+	if as_json:
+		util.silent(True)
+
 	if root and os.path.exists(root + '/.sail'):
 		raise util.SailException('This ship has already sailed. Pick another one or remove the .sail directory.')
 
@@ -82,7 +86,7 @@ def init(ctx, provider_token, email, size, region, force, namespace, environment
 		if not account.email_verified:
 			raise util.SailException('This DigitalOcean account e-mail is not verified.')
 	except:
-		raise util.SailException('Invalid prodiver token.')
+		raise util.SailException('Invalid provider token.')
 
 	if not email:
 		email = util.get_sail_default('email')
@@ -174,7 +178,14 @@ def init(ctx, provider_token, email, size, region, force, namespace, environment
 			util.item('Could not initialize Premium')
 
 	util.heading('Initialization successful')
-	_success(passwords['wp'])
+
+	if as_json:
+		_config = util.config()
+		_config.update({'password': passwords['wp']})
+		click.echo(json.dumps(_config))
+		return
+	else:
+		_success(passwords['wp'])
 
 def _success(wp_password):
 	config = util.config()
@@ -421,14 +432,19 @@ def _configure():
 	c.put(sail.TEMPLATES_PATH + '/mariadb.cnf', '/etc/mysql/mariadb.conf.d/90-sail.cnf', preserve_mode=False)
 	c.put(sail.TEMPLATES_PATH + '/logrotate.conf', '/etc/logrotate.d/sail', preserve_mode=False)
 
+	# Certbot post-deploy hook
+	c.run('mkdir -p /etc/letsencrypt/renewal-hooks/deploy/')
+	c.put(sail.TEMPLATES_PATH + '/certbot.deploy.sh', '/etc/letsencrypt/renewal-hooks/deploy/sail.sh', preserve_mode=False)
+	c.run('chmod +x /etc/letsencrypt/renewal-hooks/deploy/sail.sh')
+
 	# Make sure certbot.conf is in action.
-	c.run('systemctl reload nginx')
+	c.run('systemctl reload nginx.service')
 
 	# Make sure MariaDB config is active.
 	c.run('systemctl restart mariadb.service')
 
 	# Get xhprof
-	c.run('curl -L https://github.com/kovshenin/xhprof/releases/download/0.10.2-sail/xhprof.so.gz -o /tmp/xhprof.so.gz')
+	c.run('curl -L https://github.com/kovshenin/xhprof/releases/download/0.10.6-sail/xhprof.so.gz -o /tmp/xhprof.so.gz')
 	c.run('gunzip /tmp/xhprof.so.gz && mv /tmp/xhprof.so /usr/lib/php/20190902/xhprof.so')
 
 	# Get dhparams
@@ -437,6 +453,9 @@ def _configure():
 	# Permissions
 	c.run('chown -R www-data. /var/www')
 
+	# Make sure any sshd configs are applied
+	c.run('systemctl restart sshd.service')
+
 def _install(passwords):
 	config = util.config()
 	c = util.connection()
@@ -535,11 +554,15 @@ def _install(passwords):
 @click.option('--yes', '-y', is_flag=True, help='Force yes on the are-you-sure prompt')
 @click.option('--environment', is_flag=True, help='Force destroy environment, even if other namespaces exist')
 @click.option('--skip-dns', is_flag=True, help='Do not attempt to delete DNS records for associated domains')
-def destroy(yes, environment, skip_dns):
+@click.option('--json', 'as_json', is_flag=True, help='Suspend regular output and print results in JSON format')
+def destroy(yes, environment, skip_dns, as_json):
 	'''Destroy an application namespace and/or the environment'''
 	root = util.find_root()
 	config = util.config()
 
+	if as_json:
+		util.silent(True)
+
 	if not yes:
 		click.confirm('All application data will be scrubbed and irretrievable. Are you sure?', abort=True)
 
@@ -588,6 +611,9 @@ def destroy(yes, environment, skip_dns):
 
 	util.success('Destroyed successfully')
 
+	if as_json:
+		click.echo(json.dumps({'success': True}))
+
 def _destroy_namespace():
 	config = util.config()
 	c = util.connection()
@@ -632,7 +658,8 @@ def _destroy_environment():
 
 @cli.command()
 @click.option('--provider-token', help='Your DigitalOcean API token, must be read-write. You can set a default token with: sail config provider-token <token>')
-def sizes(provider_token):
+@click.option('--json', 'as_json', is_flag=True)
+def sizes(provider_token, as_json):
 	'''Get available droplet sizes'''
 	root = util.find_root()
 
@@ -647,23 +674,67 @@ def sizes(provider_token):
 	if not provider_token:
 		raise util.SailException('You need to provide a DigitalOcean API token with --provider-token, or set a default one with: sail config provider-token <token>')
 
-	click.echo('# Getting available droplet sizes')
-
+	sizes = []
 	manager = digitalocean.Manager(token=provider_token)
-	sizes = manager.get_all_sizes()
-	t = PrettyTable(['Size', 'Price', 'Description'])
-
-	for size in sizes:
+	for size in manager.get_all_sizes():
 		if size.available:
-			t.add_row([size.slug, size.price_monthly, size.description])
+			sizes.append(SimpleNamespace(
+				slug=size.slug,
+				price=size.price_monthly,
+				description=size.description,
+				memory=size.memory,
+				vcpus=size.vcpus,
+				disk=size.disk,
+			))
 
-	t.align = 'l'
-	t.sortby = 'Price'
-	click.echo(t.get_string())
+	if as_json:
+		click.echo(json.dumps([s.__dict__ for s in sizes]))
+		return
+
+	width, height = os.get_terminal_size()
+	slug_max_length = max([len(s.slug) for s in sizes])
+	price_max_length = max([len(str(int(s.price))) for s in sizes]) + 1
+	disk_max_length = max([len(str(int(s.disk))) for s in sizes]) + 1
+	memory_max_length = max([len(str(int(s.memory / 1024))) for s in sizes]) + 1
+
+	i = 0
+	for size in sizes:
+		slug = size.slug.rjust(slug_max_length)
+		description = size.description
+		memory = (str(int(size.memory / 1024)) + 'G').rjust(memory_max_length)
+		disk = (str(size.disk) + 'G').rjust(disk_max_length)
+		vcpus = str(size.vcpus) + 'C'
+		price = ('$' + str(int(size.price))).rjust(price_max_length)
+
+		dots_n = len(f'{slug} {description}') + len(f'{vcpus} {memory} {disk} {price}')
+		dots_n = width - dots_n - 4
+		dots = click.style('-'*dots_n, fg='bright_black')
+
+		# Add styles
+		slug = click.style(slug, fg='green')
+		description = click.style(description)
+		memory = click.style(memory, fg='bright_black')
+		disk = click.style(disk, fg='bright_black')
+		vcpus = click.style(vcpus, fg='bright_black')
+		price = click.style(price, fg='bright_black')
+
+		if i % (height / 2) == 0:
+			click.echo()
+			header = 'Slug'.rjust(slug_max_length + 1)
+			header += ' Description'
+			header += 'CPU  RAM  Disk Price '.rjust(width-len(header))
+			click.secho(header, fg='bright_black')
+			click.echo()
+
+		click.echo(f' {slug} {description} {dots} {vcpus} {memory} {disk} {price}')
+		i += 1
+
+	click.echo()
 
 @cli.command()
 @click.option('--provider-token', help='Your DigitalOcean API token, must be read-write. You can set a default token with: sail config provider-token <token>')
-def regions(provider_token):
+@click.option('--json', 'as_json', is_flag=True)
+def regions(provider_token, as_json):
 	'''Get available deployment regions'''
 	root = util.find_root()
 
@@ -678,16 +749,25 @@ def regions(provider_token):
 	if not provider_token:
 		raise util.SailException('You need to provide a DigitalOcean API token with --provider-token, or set a default one with: sail config provider-token <token>')
 
-	click.echo('# Getting available regions')
-
-	t = PrettyTable(['Slug', 'Name'])
-
 	manager = digitalocean.Manager(token=provider_token)
-	regions = manager.get_all_regions()
+	regions = []
+	for region in manager.get_all_regions():
+		if region.available:
+			regions.append(SimpleNamespace(
+				name=region.name,
+				slug=region.slug,
+			))
+
+	if as_json:
+		click.echo(json.dumps([r.__dict__ for r in regions]))
+		return
+
+	click.echo()
+	click.secho(' Slug  Region Name', fg='bright_black')
+	click.echo()
 
 	for region in regions:
-		if region.available:
-			t.add_row([region.slug, region.name])
+		click.secho(f' {region.slug}', fg='green', nl=False)
+		click.secho(f'  {region.name}')
 
-	t.align = 'l'
-	click.echo(t.get_string())
+	click.echo()
