@@ -48,27 +48,10 @@ class TestEnd2End(unittest.TestCase):
 		self.assertEqual(result.exit_code, 0)
 		self.__class__.home = result.output.strip()
 
-	def test_019_blueprint_files(self):
-		with open('/tmp/sail.files.test', 'w') as f:
-			f.write('testing %s' % self.home)
-
-		result = self.runner.invoke(cli, ['blueprint', 'test_files.yaml'])
+	def test_020_blueprint_commands(self):
+		result = self.runner.invoke(cli, ['blueprint', 'test_commands.yaml'])
 		self.assertEqual(result.exit_code, 0)
 		self.assertIn('Blueprint applied successfully', result.output)
-		self.assertIn('Skipping: /tmp/does.not.exist', result.output)
-		self.assertIn('Copying /tmp/sail.files.test', result.output)
-
-		c = util.connection()
-		r = c.run('cat /tmp/sail.files.test')
-		self.assertIn('testing %s' % self.home, r.stdout)
-
-		r = c.run('cat /tmp/sail.files.test.2')
-		self.assertIn('testing %s' % self.home, r.stdout)
-
-		r = c.run('cat /root/sail.files.test.3')
-		self.assertIn('testing %s' % self.home, r.stdout)
-
-		os.unlink('/tmp/sail.files.test')
 
 if __name__ == '__main__':
 	unittest.main()
