@@ -248,6 +248,9 @@ def rsync(args, source, destination, default_filters=True, extend_filters=[]):
 		dlog('Rsync stdout: %s' % stdout)
 		dlog('Rsync stderr: %s' % stderr)
 
+	if 'WARNING: UNPROTECTED PRIVATE KEY FILE' in stderr:
+		raise SailException('Unprotected private key file. Please fix permissions and try again.')
+
 	return (p.returncode, stdout, stderr)
 
 def connection():
@@ -334,6 +337,14 @@ def sizeof_fmt(num, suffix="B"):
 	return f'{num:.1f}Yi{suffix}'
 
 ## Formatting:
+is_silent = False
+def silent(make_silent=None):
+	global is_silent
+	if make_silent is not None:
+		is_silent = make_silent
+		loader(suspend=is_silent)
+
+	return is_silent
 
 label_w = 0
 def label_width(width):
@@ -345,16 +356,20 @@ def label(label, fg='green'):
 	return click.style(label.rjust(label_w), fg=fg)
 
 def success(message, padding=True):
+	if silent(): return
 	if padding: click.echo()
 	click.echo(click.style('Success: ', fg='green') + message)
 	if padding: click.echo()
 
 def failure(message):
+	if silent(): return
 	click.echo(click.style('Error: ', fg='red') + message)
 
 def heading(message, padding=True):
+	if silent(): return
 	if padding: click.echo()
 	click.echo(message)
 
 def item(message):
+	if silent(): return
 	click.secho('  ' + message, fg='bright_black')
